==> download.php?FileName=terralib-5.2.0.zip: share/terralib/translations/terralib_mod_edit_qt_pt_br.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>SnapOptionsDialogForm</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/ui/SnapOptionsDialogForm.ui" line="14"/>
        <source>Snap Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/ui/SnapOptionsDialogForm.ui" line="23"/>
        <source>Enable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/ui/SnapOptionsDialogForm.ui" line="28"/>
        <source>Layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/ui/SnapOptionsDialogForm.ui" line="33"/>
        <source>Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/ui/SnapOptionsDialogForm.ui" line="38"/>
        <source>Tolerance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/ui/SnapOptionsDialogForm.ui" line="43"/>
        <source>Units</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/ui/SnapOptionsDialogForm.ui" line="53"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/ui/SnapOptionsDialogForm.ui" line="73"/>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/ui/SnapOptionsDialogForm.ui" line="80"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::edit::AggregateAreaTool</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/AggregateAreaTool.cpp" line="99"/>
        <location filename="../../../src/terralib/edit/qt/tools/AggregateAreaTool.cpp" line="115"/>
        <location filename="../../../src/terralib/edit/qt/tools/AggregateAreaTool.cpp" line="128"/>
        <location filename="../../../src/terralib/edit/qt/tools/AggregateAreaTool.cpp" line="259"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/AggregateAreaTool.cpp" line="128"/>
        <source>Error aggregating area to the polygon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/AggregateAreaTool.cpp" line="99"/>
        <location filename="../../../src/terralib/edit/qt/tools/AggregateAreaTool.cpp" line="115"/>
        <source>Could not join.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/AggregateAreaTool.cpp" line="259"/>
        <source>The geometry cannot be selected from the layer. Details:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::edit::DeleteGeometryByAreaTool</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/DeleteGeometryByAreaTool.cpp" line="243"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/DeleteGeometryByAreaTool.cpp" line="243"/>
        <source>The selection cannot be retrieved from the layer. Details:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::edit::DeleteGeometryTool</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/DeleteGeometryTool.cpp" line="68"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/DeleteGeometryTool.cpp" line="68"/>
        <source>The geometry cannot be selected from the layer.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::edit::DeletePartTool</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/DeletePartTool.cpp" line="75"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/DeletePartTool.cpp" line="75"/>
        <source>The geometry cannot be selected from the layer.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::edit::EditInfoTool</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/EditInfoTool.cpp" line="72"/>
        <source>Edit Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/EditInfoTool.cpp" line="82"/>
        <source>Property</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/EditInfoTool.cpp" line="82"/>
        <source>Value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/EditInfoTool.cpp" line="90"/>
        <source>&amp;Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/EditInfoTool.cpp" line="91"/>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/EditInfoTool.cpp" line="191"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/EditInfoTool.cpp" line="191"/>
        <source>The geometry cannot be selected from the layer. Details:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::edit::MergeGeometriesTool</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/MergeGeometriesTool.cpp" line="102"/>
        <location filename="../../../src/terralib/edit/qt/tools/MergeGeometriesTool.cpp" line="306"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/MergeGeometriesTool.cpp" line="102"/>
        <source>All geometries selected must touch!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/MergeGeometriesTool.cpp" line="106"/>
        <source>Allow to merge geometries selecting the geom_id that will keep the attributes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/MergeGeometriesTool.cpp" line="118"/>
        <location filename="../../../src/terralib/edit/qt/tools/MergeGeometriesTool.cpp" line="185"/>
        <source>Merge Geometries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/MergeGeometriesTool.cpp" line="118"/>
        <source>Pick Feature Failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/MergeGeometriesTool.cpp" line="306"/>
        <source>The geometry cannot be selected from the layer. Details:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::edit::MoveGeometryTool</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/MoveGeometryTool.cpp" line="192"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/MoveGeometryTool.cpp" line="192"/>
        <source>The geometry cannot be selected from the layer. Details:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::edit::SnapOptionsDialog</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/SnapOptionsDialog.cpp" line="114"/>
        <source>vertex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/SnapOptionsDialog.cpp" line="133"/>
        <source>pixels</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::edit::SplitPolygonTool</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/SplitPolygonTool.cpp" line="267"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/SplitPolygonTool.cpp" line="267"/>
        <source>The geometry cannot be selected from the layer. Details:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::edit::SubtractAreaTool</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/SubtractAreaTool.cpp" line="94"/>
        <location filename="../../../src/terralib/edit/qt/tools/SubtractAreaTool.cpp" line="110"/>
        <location filename="../../../src/terralib/edit/qt/tools/SubtractAreaTool.cpp" line="123"/>
        <location filename="../../../src/terralib/edit/qt/tools/SubtractAreaTool.cpp" line="256"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/SubtractAreaTool.cpp" line="123"/>
        <source>Error subtracting area to the polygon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/SubtractAreaTool.cpp" line="94"/>
        <location filename="../../../src/terralib/edit/qt/tools/SubtractAreaTool.cpp" line="110"/>
        <source>Could not subtract.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/SubtractAreaTool.cpp" line="256"/>
        <source>The geometry cannot be selected from the layer. Details:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::edit::VertexTool</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/VertexTool.cpp" line="305"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/VertexTool.cpp" line="305"/>
        <source>The geometry cannot be selected from the layer. Details:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> download.php?FileName=terralib-5.3.2.zip: share/terralib/translations/terralib_mod_edit_qt_pt_br.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt_BR">
<context>
    <name>SnapOptionsDialogForm</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/ui/SnapOptionsDialogForm.ui" line="14"/>
        <source>Snap Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/ui/SnapOptionsDialogForm.ui" line="23"/>
        <source>Enable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/ui/SnapOptionsDialogForm.ui" line="28"/>
        <source>Layer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/ui/SnapOptionsDialogForm.ui" line="33"/>
        <source>Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/ui/SnapOptionsDialogForm.ui" line="38"/>
        <source>Tolerance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/ui/SnapOptionsDialogForm.ui" line="43"/>
        <source>Units</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/ui/SnapOptionsDialogForm.ui" line="53"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/ui/SnapOptionsDialogForm.ui" line="73"/>
        <source>Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/ui/SnapOptionsDialogForm.ui" line="80"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::edit::AggregateAreaTool</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/AggregateAreaTool.cpp" line="97"/>
        <location filename="../../../src/terralib/edit/qt/tools/AggregateAreaTool.cpp" line="113"/>
        <location filename="../../../src/terralib/edit/qt/tools/AggregateAreaTool.cpp" line="126"/>
        <location filename="../../../src/terralib/edit/qt/tools/AggregateAreaTool.cpp" line="257"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/AggregateAreaTool.cpp" line="126"/>
        <source>Error aggregating area to the polygon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/AggregateAreaTool.cpp" line="97"/>
        <location filename="../../../src/terralib/edit/qt/tools/AggregateAreaTool.cpp" line="113"/>
        <source>Could not join.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/AggregateAreaTool.cpp" line="257"/>
        <source>The geometry cannot be selected from the layer. Details:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::edit::CreatePolygonTool</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/CreatePolygonTool.cpp" line="155"/>
        <location filename="../../../src/terralib/edit/qt/tools/CreatePolygonTool.cpp" line="171"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/CreatePolygonTool.cpp" line="155"/>
        <location filename="../../../src/terralib/edit/qt/tools/CreatePolygonTool.cpp" line="171"/>
        <source>Could not create.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::edit::DeleteGeometryByAreaTool</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/DeleteGeometryByAreaTool.cpp" line="249"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/DeleteGeometryByAreaTool.cpp" line="249"/>
        <source>The selection cannot be retrieved from the layer. Details:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::edit::DeleteGeometryTool</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/DeleteGeometryTool.cpp" line="69"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/DeleteGeometryTool.cpp" line="69"/>
        <source>The geometry cannot be selected from the layer.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::edit::DeletePartTool</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/DeletePartTool.cpp" line="77"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/DeletePartTool.cpp" line="77"/>
        <source>The geometry cannot be selected from the layer.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::edit::EditInfoTool</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/EditInfoTool.cpp" line="72"/>
        <source>Edit Information</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/EditInfoTool.cpp" line="82"/>
        <source>Property</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/EditInfoTool.cpp" line="82"/>
        <source>Value</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/EditInfoTool.cpp" line="90"/>
        <source>&amp;Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/EditInfoTool.cpp" line="91"/>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/EditInfoTool.cpp" line="188"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/EditInfoTool.cpp" line="188"/>
        <source>The geometry cannot be selected from the layer. Details:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::edit::MergeGeometriesTool</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/MergeGeometriesTool.cpp" line="102"/>
        <location filename="../../../src/terralib/edit/qt/tools/MergeGeometriesTool.cpp" line="337"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/MergeGeometriesTool.cpp" line="102"/>
        <source>All geometries selected must touch!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/MergeGeometriesTool.cpp" line="106"/>
        <source>Allow to merge geometries selecting the geom_id that will keep the attributes.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/MergeGeometriesTool.cpp" line="114"/>
        <location filename="../../../src/terralib/edit/qt/tools/MergeGeometriesTool.cpp" line="121"/>
        <location filename="../../../src/terralib/edit/qt/tools/MergeGeometriesTool.cpp" line="151"/>
        <location filename="../../../src/terralib/edit/qt/tools/MergeGeometriesTool.cpp" line="197"/>
        <source>Merge Geometries</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/MergeGeometriesTool.cpp" line="114"/>
        <source>Invalid bounding box.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/MergeGeometriesTool.cpp" line="121"/>
        <source>Pick Feature Failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/MergeGeometriesTool.cpp" line="151"/>
        <source>Could not merge.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/MergeGeometriesTool.cpp" line="337"/>
        <source>The geometry cannot be selected from the layer. Details:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::edit::MoveGeometryTool</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/MoveGeometryTool.cpp" line="194"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/MoveGeometryTool.cpp" line="194"/>
        <source>The geometry cannot be selected from the layer. Details:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::edit::RotateGeometryTool</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/RotateGeometryTool.cpp" line="138"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/RotateGeometryTool.cpp" line="138"/>
        <source>The geometry cannot be selected from the layer. Details:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/RotateGeometryTool.cpp" line="193"/>
        <source> deg</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::edit::SnapOptionsDialog</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/SnapOptionsDialog.cpp" line="119"/>
        <source>vertex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/SnapOptionsDialog.cpp" line="139"/>
        <source>pixels</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::edit::SplitPolygonTool</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/SplitPolygonTool.cpp" line="202"/>
        <location filename="../../../src/terralib/edit/qt/tools/SplitPolygonTool.cpp" line="299"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/SplitPolygonTool.cpp" line="202"/>
        <source>Could not split.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/SplitPolygonTool.cpp" line="257"/>
        <source>TerraAmazon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/SplitPolygonTool.cpp" line="258"/>
        <source>To use this tool, you must select at least one geometry.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/SplitPolygonTool.cpp" line="299"/>
        <source>The geometry cannot be selected from the layer. Details:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::edit::SubtractAreaTool</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/SubtractAreaTool.cpp" line="92"/>
        <location filename="../../../src/terralib/edit/qt/tools/SubtractAreaTool.cpp" line="108"/>
        <location filename="../../../src/terralib/edit/qt/tools/SubtractAreaTool.cpp" line="121"/>
        <location filename="../../../src/terralib/edit/qt/tools/SubtractAreaTool.cpp" line="254"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/SubtractAreaTool.cpp" line="121"/>
        <source>Error subtracting area to the polygon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/SubtractAreaTool.cpp" line="92"/>
        <location filename="../../../src/terralib/edit/qt/tools/SubtractAreaTool.cpp" line="108"/>
        <source>Could not subtract.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/SubtractAreaTool.cpp" line="254"/>
        <source>The geometry cannot be selected from the layer. Details:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>te::edit::VertexTool</name>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/VertexTool.cpp" line="305"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../src/terralib/edit/qt/tools/VertexTool.cpp" line="305"/>
        <source>The geometry cannot be selected from the layer. Details:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
